Uses of Class org.openqa.selenium.server.browserlaunchers.InvalidBrowserExecutableException (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.InvalidBrowserExecutableException

Packages that use InvalidBrowserExecutableException
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of InvalidBrowserExecutableException in org.openqa.selenium.server.browserlaunchers

Constructors in org.openqa.selenium.server.browserlaunchers that throw InvalidBrowserExecutableException
`FirefoxChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserString)`
`FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`
`FirefoxLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.